@@ -1,5 +1,6 @@
 package HTML::FormHandler::TraitFor::Types;
 # ABSTRACT: types used internally in FormHandler
+$HTML::FormHandler::TraitFor::Types::VERSION = '0.40067';
 use Moose::Role;
 use Moose::Util::TypeConstraints;
 
@@ -31,6 +32,15 @@ coerce 'HFH::SelectOptions'
          return $opts;
      };
 
+coerce 'HFH::SelectOptions'
+  => from 'ArrayRef[ArrayRef]'
+  => via {
+         my @options = @{ $_[0][0] };
+         my $opts;
+         push @{$opts}, { value => $_, label => $_ } foreach @options;
+         return $opts;
+     };
+
 no Moose::Util::TypeConstraints;
 1;
 
@@ -46,7 +56,7 @@ HTML::FormHandler::TraitFor::Types - types used internally in FormHandler
 
 =head1 VERSION
 
-version 0.40064
+version 0.40067
 
 =head1 AUTHOR
 
@@ -54,7 +64,7 @@ FormHandler Contributors - see HTML::FormHandler
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Gerda Shank.
+This software is copyright (c) 2016 by Gerda Shank.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
